#!/usr/bin/perl

#┌─────────────────────────────────
#│ Quick DB : quick.cgi - 2022/05/28
#│ copyright (c) kentweb, 1997-2022
#│ https://www.kent-web.com/
#└─────────────────────────────────
# REBUILD(改造)
#┌─────────────────────────────────
#│  Quick DB v4.1 PLUS 2022/05/28
#│  Edited by TRANSFORM Since 2012
#│  https://www.transformsite.com/
#└─────────────────────────────────

# モジュール宣言
use strict;
use CGI::Carp qw(fatalsToBrowser);
use lib "./lib";
use CGI::Minimal;

# 設定ファイル認識
require "./init.cgi";
my %cf = set_init();

# データ受理
CGI::Minimal::max_read_size($cf{maxdata});
my $cgi = CGI::Minimal->new;
error('容量オーバー') if ($cgi->truncated);
my %in = parse_form($cgi);

# 検索
if ($in{mode} eq 'find') { find_db(); }
if ($in{mode} eq "read") { read_log(); }
main_page();

#-----------------------------------------------------------
#  メインページ
#-----------------------------------------------------------
sub main_page {
	# カテゴリ
	my %op;
	foreach my $i (1 .. 3) {
		foreach my $op (0 .. $#{$cf{"cate$i"}}) {
			$op{$i} .= qq|<option value="$op">$cf{"cate$i"}->[$op]\n|;
		}
	}

	my $news = new_list();

	# テンプレート読み込み
	open(IN,"$cf{tmpldir}/quick.html") or error('open err: quick.html');
	my $tmpl = join('', <IN>);
	close(IN);

	# 文字置き換え
	$tmpl =~ s/!home!/$cf{topurl}/g;
	$tmpl =~ s/!html_title!/$cf{html_title}/g;
	$tmpl =~ s|!bbs_css!|$cf{cmnurl}/style.css|g;
	$tmpl =~ s|!mob_css!|$cf{cmnurl}/style_mobile.css|g;
	$tmpl =~ s|!cmnurl!|$cf{cmnurl}|g;
	$tmpl =~ s/!db_cgi!/$cf{db_cgi}/g;
	$tmpl =~ s/!admin_cgi!/$cf{admin_cgi}/g;
	$tmpl =~ s/!box-([1-3])!/$cf{categ}->[$1-1]/g;
	$tmpl =~ s/<!-- op-([1-3]) -->/$op{$1}/g;
	$tmpl =~ s/!word!/$in{word}/g;
	$tmpl =~ s/!news!/$news/g;
	$tmpl =~ s/!new_logs!/$cf{new_logs}/g;

	# 表示
	print "Content-type: text/html; charset=utf-8\n\n";
	footer($tmpl);
}

#-----------------------------------------------------------
#  新着表示
#-----------------------------------------------------------
sub new_list {

	# データベース展開
	my (@log,$news);
	open(IN,"$cf{datadir}/db.cgi") or error('open err: db.cgi');
	my @tmp = <IN>;
	close(IN);
	# reverse order表示
	@tmp = reverse(@tmp);
	foreach(@tmp) {
		my ($no,$ttl,$com,$cat1,$cat2,$cat3,$e1,$w1,$h1,$e2,$w2,$h2,$e3,$w3,$h3) = split(/<>/);
		if (defined($no)) { push(@log,$_); }
	}

	my $i;
	foreach (@log) {
		my ($no,$ttl,$com,$cat1,$cat2,$cat3,$e1,$w1,$h1,$e2,$w2,$h2,$e3,$w3,$h3) = split(/<>/);
		$i++;
		last if ($i >= $cf{new_logs} + 1);

		# 文字カット
		if (length($com) > 100) {
			$com = substr($com,0,93) . '.......';
		}

		# 添付あり
		my $clip; 
		$clip = news_attach($no,$e1,$w1,$h1,$e2,$w2,$h2,$e3,$w3,$h3);

		my %cat = (1 => $cat1, 2 => $cat2, 3 => $cat3);

		$news .= qq|<div id="news"><div id="image">$clip</div>○ <a href="$cf{db_cgi}?mode=read&no=$no">$ttl</a> [ $cf{cate1}->[$cat{1}],$cf{cate2}->[$cat{2}],$cf{cate3}->[$cat{3}] ]<br />$com<div class="clear"></div></div>\n|;
	}

	$news = qq|$news\n|;

	# 結果を返す
	return $news;
}

#-----------------------------------------------------------
#  新着記事閲覧
#-----------------------------------------------------------
sub read_log {
	# ページ数
	$in{pg} =~ s/\D//g;
	my $pg = $in{pg} || 0;

	my $i = 0;
	my ($flg,%r);
	open(DB,"$cf{datadir}/db.cgi") or &error("open err: $cf{datadir}/db.cgi");
	while (<DB>) {
		chomp;
		my ($no,$ttl,$com,$cat1,$cat2,$cat3,$e1,$w1,$h1,$e2,$w2,$h2,$e3,$w3,$h3) = split(/<>/);
		if ($in{no} == $no) {
			$flg = 1;
			$r{com} = $com;
			$r{ttl} = $ttl;
			$r{e1} = $e1;
			$r{w1}   = $w1;
			$r{h1}   = $h1;
			$r{e2} = $e2;
			$r{w2}   = $w2;
			$r{h2}   = $h2;
			$r{e3} = $e3;
			$r{w3}   = $w3;
			$r{h3}   = $h3;
			$r{cat1}   = $cat1;
			$r{cat2}   = $cat2;
			$r{cat3}   = $cat3;
		}

		# 表示件数を分ける
		$i++;
		next if ($i < $pg + 1);
		next if ($i > $pg + $cf{logs});
	}
	close(DB);

	# 不正エラー
	if ($pg > $i) { error('ページ数が不正です'); }

		my %cat = (1 => $r{cat1}, 2 => $r{cat2}, 3 => $r{cat3});

		# 添付あり
		my $clip; 
		$clip = attach($in{no},$r{e1},$r{w1},$r{h1},$r{e2},$r{w2},$r{h2},$r{e3},$r{w3},$r{h3});

		# 自動リンク
		$r{com} = auto_link($r{com}) if ($cf{auto_link});

	# テンプレート認識
	open(IN,"$cf{tmpldir}/new_read.html") or &error("open err: new_read.html");
	my $tmpl = join('', <IN>);
	close(IN);

	# 文字置き換え
	$tmpl =~ s/!db_cgi!/$cf{db_cgi}/g;
	$tmpl =~ s/!html_title!/$cf{html_title}/g;
	$tmpl =~ s|!bbs_css!|$cf{cmnurl}/style.css|g;
	$tmpl =~ s|!mob_css!|$cf{cmnurl}/style_mobile.css|g;
	$tmpl =~ s|!cmnurl!|$cf{cmnurl}|g;
	$tmpl =~ s/!admin_cgi!/$cf{admin_cgi}/g;
	$tmpl =~ s/!num!/$in{no}/g;
	$tmpl =~ s/!title!/$r{ttl}/g;
	$tmpl =~ s/!box-([1-3])!/$cf{categ}->[$1-1]/g;
	$tmpl =~ s/!cat-([1-3])!/$cf{"cate$1"}->[$cat{$1}]/g;
	$tmpl =~ s/!comment!/$r{com}/g;
	$tmpl =~ s/!clip!/$clip/g;
	$tmpl =~ s|<!-- pager -->|make_pager($i,$pg)|eg;

	# 表示
	print "Content-type: text/html; charset=utf-8\n\n";
	footer($tmpl);
}

#-----------------------------------------------------------
#  検索
#-----------------------------------------------------------
sub find_db {
	# ページ数
	$in{pg} =~ s/\D//g;
	my $pg = $in{pg} || 0;
	
	# UTF-8定義
	my $byte1 = '[\x00-\x7f]';
	my $byte2 = '[\xC0-\xDF][\x80-\xBF]';
	my $byte3 = '[\xE0-\xEF][\x80-\xBF]{2}';
	my $byte4 = '[\xF0-\xF7][\x80-\xBF]{3}';

	# キーワード処理
	$in{word} =~ s/　/ /g;
	my @wd = split(/\s+/,$in{word});

	# データベース展開
	my $i = 0;
	my @log;
	open(DB,"$cf{datadir}/db.cgi") or error('open err: db.cgi');
	while(<DB>) {
		my ($no,$ttl,$com,$cat1,$cat2,$cat3,$e1,$w1,$h1,$e2,$w2,$h2,$e3,$w3,$h3) = split(/<>/);

		# カテゴリ検索
		next if ($in{cat1} != $cat1 && $in{cat1} ne '');
		next if ($in{cat2} != $cat2 && $in{cat2} ne '');
		next if ($in{cat3} != $cat3 && $in{cat3} ne '');

		# ワード検索
		if ($in{word} ne '') {
			my $flg;
			foreach my $wd (@wd) {
				if ($com =~ /^(?:$byte1|$byte2|$byte3|$byte4)*?\Q$wd\E/i) {
					$flg++;
				} else {
					$flg = 0;
					last;
				}
			}
			next if (!$flg);
		}

		# 表示件数を分ける
		$i++;
		next if ($i < $pg + 1);
		next if ($i > $pg + $cf{logs});

		push(@log,$_);
	}
	close(DB);

	# 不正エラー
	if ($pg > $i) { error('ページ数が不正です'); }

	# テンプレート読み込み
	open(IN,"$cf{tmpldir}/find.html") or error('open err: find.html');
	my $tmpl = join('', <IN>);
	close(IN);

	# 文字置換
	$tmpl =~ s/!db_cgi!/$cf{db_cgi}/g;
	$tmpl =~ s/!html_title!/$cf{html_title}/g;
	$tmpl =~ s|!bbs_css!|$cf{cmnurl}/style.css|g;
	$tmpl =~ s|!mob_css!|$cf{cmnurl}/style_mobile.css|g;
	$tmpl =~ s|!cmnurl!|$cf{cmnurl}|g;
	$tmpl =~ s/!admin_cgi!/$cf{admin_cgi}/g;
	$tmpl =~ s/!hit!/$i/g;
	$tmpl =~ s|<!-- pager -->|make_pager($i,$pg)|eg;

	# テンプレート分割
	my ($head,$loop,$foot) = $tmpl =~ m|(.+)<!-- loop -->(.+?)<!-- /loop -->(.+)|s
			? ($1,$2,$3)
			: error('テンプレート不正');

	# 画面表示
	print "Content-type: text/html; charset=utf-8\n\n";
	print $head;

	my @rlog = reverse(@log);
	# 検索結果展開
	foreach (@rlog) {
		my ($no,$ttl,$com,$cat1,$cat2,$cat3,$e1,$w1,$h1,$e2,$w2,$h2,$e3,$w3,$h3) = split(/<>/);
		my %cat = (1 => $cat1, 2 => $cat2, 3 => $cat3);

		# 添付あり
		my $clip; 
		$clip = attach($no,$e1,$w1,$h1,$e2,$w2,$h2,$e3,$w3,$h3);

		# 自動リンク
		$com = auto_link($com) if ($cf{auto_link});

		# 置換
		my $tmp = $loop;
		$tmp =~ s/!title!/$ttl/g;
		$tmp =~ s/!box-([1-3])!/$cf{categ}->[$1-1]/g;
		$tmp =~ s/!cat-([1-3])!/$cf{"cate$1"}->[$cat{$1}]/g;
		$tmp =~ s/!comment!/$com/g;
		$tmp =~ s/!clip!/$clip/g;
		$tmp =~ s/!res_com!/$cf{bbs_cgi}?mode=rescom&no=$no/g;
		$tmp =~ s/!ico_com!/$cf{ico_com}/g;
		print $tmp;
	}

	# フッター
	footer($foot);
}

#-----------------------------------------------------------
#  クッキー取得
#-----------------------------------------------------------
sub get_cookie {
	# クッキー取得
	$ENV{HTTP_COOKIE} =~ /$cf{cookie_id}=(.+);?/;
	my $cookie = $1;

	# URLデコード
	my @cook;
	foreach ( split(/<>/,$cookie) ) {
		s/%([0-9A-Fa-f][0-9A-Fa-f])/pack("H2", $1)/eg;
		s/[&"'<>]//g;

		push(@cook,$_);
	}
	return @cook;
}

#-----------------------------------------------------------
#  完了メッセージ
#-----------------------------------------------------------
sub message {
	my ($msg) = @_;

	open(IN,"$cf{tmpldir}/message.html") or error("open err: message.html");
	my $tmpl = join('', <IN>);
	close(IN);

	$tmpl =~ s/!html_title!/$cf{html_title}/g;
	$tmpl =~ s|!bbs_css!|$cf{cmnurl}/style.css|g;
	$tmpl =~ s|!mob_css!|$cf{cmnurl}/style_mobile.css|g;
	$tmpl =~ s/!db_cgi!/$cf{db_cgi}/g;
	$tmpl =~ s/!message!/$msg/g;

	print "Content-type: text/html; charset=utf-8\n\n";
	print $tmpl;
	exit;
}

#-----------------------------------------------------------
#  繰越ボタン作成
#-----------------------------------------------------------
sub make_pager {
	my ($i,$pg) = @_;
	
	# ページ繰越定義
	$cf{logs} ||= 10;
	my $next = $pg + $cf{logs};
	my $back = $pg - $cf{logs};
	
	# 引数
	my $param;
	$param .= "&amp;word=" . url_encode($in{word}) if ($in{word} ne '');
	$param .= "&amp;cat1=$in{cat1}" if ($in{cat1} ne '');
	$param .= "&amp;cat2=$in{cat2}" if ($in{cat2} ne '');
	$param .= "&amp;cat3=$in{cat3}" if ($in{cat3} ne '');
	
	# ページ繰越ボタン作成
	if ($back >= 0 or $next < $i) {
		my ($pager,$n);
		$n = $i;
		
		if ($back >= 0) {
			$pager .= qq|<a href="$cf{db_cgi}?mode=find&amp;pg=$back$param" class="page gradient">first</a>\n|;
		}
		
		my ($x,$y) = (1,0);
		while ($i > 0) {
			if ($pg == $y) {
				$pager .= qq|<span class="page active">$x</span>\n|;
			} else {
				$pager .= qq|<a href="$cf{db_cgi}?mode=find&amp;pg=$y$param" class="page gradient">$x</a>\n|;
			}
			$x++;
			$y += $cf{logs};
			$i -= $cf{logs};
		}
		
		if ($next < $n) {
			$pager .= qq|<a href="$cf{db_cgi}?mode=find&amp;pg=$next$param" class="page gradient">last</a>\n|;
		}
		
		return qq|<div class="pager">$pager</div>|;
	} else {
		return;
	}
}

#-----------------------------------------------------------
#  フォームデコード
#-----------------------------------------------------------
sub parse_form {
	my $cgi = shift;

	my %in;
	foreach ( $cgi->param() ) {
		my $val = $cgi->param($_);

		# 無害化
		if ($_ ne 'upfile') {
			$val =~ s/&/&amp;/g;
			$val =~ s/"/&quot;/g;
			$val =~ s/</&lt;/g;
			$val =~ s/>/&gt;/g;
			$val =~ s/'/&#39;/g;
			$val =~ s/\r\n/<br>/g;
			$val =~ s/\r/<br>/g;
			$val =~ s/\n/<br>/g;
		}
		$in{$_} = $val;
	}
	return %in;
}

#-----------------------------------------------------------
#  フッター
#-----------------------------------------------------------
sub footer {
	my $foot = shift;

	# 著作権表記（削除・改変禁止）
	my $copy = <<EOM;
<p style="margin-top:0.5em;text-align:center;font-family:Verdana,Helvetica,Arial;font-size:11pt;">
- <a href="https://www.kent-web.com/" target="_top">$cf{version}</a> -<br>
++ <a href="https://www.transformsite.com/" target="_top">Edited by TRANSFORM</a> ++
</p>
EOM

	if ($foot =~ /(.+)(<\/body[^>]*>.*)/si) {
		print "$1$copy$2\n";
	} else {
		print "$foot$copy\n";
		print "</body></html>\n";
	}
	exit;
}

#-----------------------------------------------------------
#  エラー画面
#-----------------------------------------------------------
sub error {
	my $err = shift;

	open(IN,"$cf{tmpldir}/error.html") or die;
	my $tmpl = join('', <IN>);
	close(IN);

	$tmpl =~ s/!html_title!/$cf{html_title}/g;
	$tmpl =~ s|!bbs_css!|$cf{cmnurl}/style.css|g;
	$tmpl =~ s|!mob_css!|$cf{cmnurl}/style_mobile.css|g;
	$tmpl =~ s/!error!/$err/g;

	print "Content-type: text/html; charset=utf-8\n\n";
	print $tmpl;
	exit;
}

#-----------------------------------------------------------
#  URLエンコード
#-----------------------------------------------------------
sub url_encode {
	my $str = shift;

	$str =~ s/([^\w ])/'%'.unpack('H2', $1)/eg;
	$str =~ tr/ /+/;
	return $str;
}

#-----------------------------------------------------------
#  取り扱いファイル
#-----------------------------------------------------------
sub ext_file {
	my $ext;
	foreach ( keys %cf ) {
		next if ($_ !~ /^ok_(\w+)/);
		my $file = $1;
		next if (!$cf{$_});

		$file =~ tr/a-z/A-Z/;
		$ext .= "$file, ";
	}
	$ext =~ s/, $//;

	return $ext;
}

#-----------------------------------------------------------
#  ファイル容量
#-----------------------------------------------------------
sub get_size {
	my $file = shift;
	
	my $size = -s $file || 0;
	return $size > 1024 ? comma(int($size/1024)) . 'KB' : $size . 'Bytes';
}

#-----------------------------------------------------------
#  桁区切り
#-----------------------------------------------------------
sub comma {
	local($_) = @_;

	1 while s/(.*\d)(\d\d\d)/$1,$2/;
	$_;
}

#-----------------------------------------------------------
#  添付表示
#-----------------------------------------------------------
sub attach {
	my $no = shift;
	my (%e,%w,%h);
	($e{1},$w{1},$h{1},$e{2},$w{2},$h{2},$e{3},$w{3},$h{3}) = @_;

	my $ret;
	foreach my $i (1 .. 3) {
		next if (!$e{$i});

		# 画像以外の場合
		if ($e{$i} !~ /^\.(jpg|gif|png)$/) {
			my $size = -s "$cf{upldir}/$no-$i$e{$i}";
			$size = int(($size / 1024) + 0.5) . 'KB';
			my $icon = defined($cf{ext}{$e{$i}}) ? $cf{ext}{$e{$i}} : $cf{ext_o};
			$ret .= qq|<a href="$cf{uplurl}/$no-$i$e{$i}" target="_blank"><img src="$cf{iconurl}/$icon" align="right" hspace="8" border="0" alt="$icon"></a><br clear="all">|;
			#$ret .= qq|[添付]: <a href="$cf{uplurl}/$no-$i$e{$i}" target="_blank">$no-$i$e{$i}</a> ($size)\n|;

		# 画像の場合
		} elsif (-f "$cf{upldir}/$no-s-$i$e{$i}") {
			$ret .= qq|<a href="$cf{uplurl}/$no-$i$e{$i}" target="_blank"><img src="$cf{uplurl}/$no-s-$i$e{$i}" class="img"></a>|;

		} else {
			my ($w,$h) = resize($w{$i},$h{$i});
			$ret .= qq|<a href="$cf{uplurl}/$no-$i$e{$i}" class="lightview" data-lightview-title="" data-lightview-group="quick-set" data-lightview-group-options="skin: 'mac'"><img src="$cf{uplurl}/$no-$i$e{$i}" width="$w" height="$h" hspace="10" vspace="5" class="img"></a>|;
		}
	}
	return $ret;
}

#-----------------------------------------------------------
#  新着表示添付
#-----------------------------------------------------------
sub news_attach {
	my $no = shift;
	my (%e,%w,%h);
	($e{1},$w{1},$h{1},$e{2},$w{2},$h{2},$e{3},$w{3},$h{3}) = @_;

	my $ret;
	foreach my $i (1 .. 3) {
		next if (!$e{$i});

		# 画像以外の場合
		if ($e{$i} !~ /^\.(jpg|gif|png)$/) {
			my $size = -s "$cf{upldir}/$no-$i$e{$i}";
			$size = int(($size / 1024) + 0.5) . 'KB';
			my $icon = defined($cf{ext}{$e{$i}}) ? $cf{ext}{$e{$i}} : $cf{ext_o};
			$ret .= qq|<a href="$cf{uplurl}/$no-$i$e{$i}" target="_blank"><img src="$cf{iconurl}/$icon" align="right" hspace="8" border="0" alt=""></a><br clear="all">|;
			#$ret .= qq|[添付]: <a href="$cf{uplurl}/$no-$i$e{$i}" target="_blank">$no-$i$e{$i}</a> ($size)\n|;

		# 画像の場合
		} elsif (-f "$cf{upldir}/$no-s-$i$e{$i}") {
			$ret .= qq|<a href="$cf{uplurl}/$no-$i$e{$i}" target="_blank"><img src="$cf{uplurl}/$no-s-$i$e{$i}" class="img"></a>|;

		} else {
			my ($w,$h) = news_resize($w{$i},$h{$i});
			$ret .= qq|<a href="$cf{uplurl}/$no-$i$e{$i}" class="lightview" data-lightview-title="" data-lightview-group="quick-set" data-lightview-group-options="skin: 'mac'"><img src="$cf{uplurl}/$no-$i$e{$i}" width="$w" height="$h" hspace="10" vspace="5" class="img"></a>|;
		}
	}
	return $ret;
}

#-----------------------------------------------------------
#  自動リンク
#-----------------------------------------------------------
sub auto_link {
	my $text = shift;

	$text =~ s/(s?https?:\/\/([\w-.!~*'();\/?:\@=+\$,%#]|&amp;)+)/<a href="$1" target="_blank">$1<\/a>/g;
	return $text;
}

#-----------------------------------------------------------
#  ファイルチェック
#-----------------------------------------------------------
sub check_upl {
	my ($ext) = @_;

	# mimeタイプ
	my $mime = $cgi->param_mime('upfile');

	# text
	my $flg;
	if ($ext eq '.txt' && $cf{ok_text} && $mime =~ /^text\/plain$/i) { $flg++; }
	elsif ($ext eq '.gif' && $cf{ok_gif} && $mime =~ /^image\/gif$/i) { check_gif(); $flg++; }
	elsif ($ext eq '.png' && $cf{ok_png} && $mime =~ /^image\/(x-)?png$/i) { check_png(); $flg++; }
	elsif ($ext eq '.jpg' && $cf{ok_jpeg} && $mime =~ /^image\/p?jpe?g$/i) { check_jpg(); $flg++; }
	elsif ($ext eq '.xls' && $cf{ok_excel} && $mime =~ /^application\/(vnd\.)?ms-?excel$/i) { $flg++; }
	elsif ($ext eq '.xlsx' && $cf{ok_excel} && $mime =~ /^application\/vnd\.openxmlformats-officedocument\.spreadsheetml\.sheet$/i) { $flg++; }
	elsif ($ext eq '.doc' && $cf{ok_word} && $mime =~ /^application\/(vnd\.)?ms-?word$/i) { $flg++; }
	elsif ($ext eq '.docx' && $cf{ok_word} && $mime =~ /^application\/vnd\.openxmlformats-officedocument\.wordprocessingml\.document$/i) { $flg++; }
	elsif ($ext eq '.ppt' && $cf{ok_ppt} && $mime =~ /^application\/(vnd\.)?ms-?powerpoint$/i) { $flg++; }
	elsif ($ext eq '.pptx' && $cf{ok_ppt} && $mime =~ /^application\/vnd\.openxmlformats-officedocument\.presentationml\.presentation$/i) { $flg++; }
	elsif ($ext eq '.zip' && $cf{ok_zip} && $mime =~ /^application\/(x-)?zip(-compressed)?$/i) { $flg++; }
	elsif ($ext eq '.pdf' && $cf{ok_pdf} && $mime =~ /^application\/pdf$/i) { $flg++; }

	if (!$flg) { error('このファイルは取り扱いできません'); }
}

#-----------------------------------------------------------
#  GIFチェック
#-----------------------------------------------------------
sub check_gif {
	# マジックバイト確認
	if ($in{upfile} !~ /^gif8[79]a/i) { error('このGIF画像は取扱できません!!'); }
}

#-----------------------------------------------------------
#  PNGチェック
#-----------------------------------------------------------
sub check_png {
	# XSS文字
	if ($in{upfile} =~ /script|embed|object|iframe|onclick|onblur|onchange|onmouse|onError|onload|onfocus|onselect|onsubmit|onunload|onreset|onabort|ondblclick|onkey|ondragdrop/i) {
		error('このPNG画像は取扱できません!');
	}
	# マジックバイト確認
	if ($in{upfile} !~ /^\x89PNG/i) { error('このPNG画像は取扱できません!!'); }
}

#-----------------------------------------------------------
#  JPEGチェック
#-----------------------------------------------------------
sub check_jpg {
	# マジックバイト確認
	if ($in{upfile} !~ /\xff\xd8/) { error('このJPEG画像は取扱できません!!'); }
}

#-----------------------------------------------------------
#  入力チェック
#-----------------------------------------------------------
sub check_input {
	my $err;
	if ($in{cat1} eq '') { $err .= "$cf{categ}[0] が未入力です<br />"; }
	if ($in{cat2} eq '') { $err .= "$cf{categ}[1] が未入力です<br />"; }
	if ($in{cat3} eq '') { $err .= "$cf{categ}[2] が未入力です<br />"; }
	error($err) if ($err);
}

